summaryrefslogtreecommitdiff
path: root/nuttx/arch/avr/src/avr32
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/arch/avr/src/avr32')
-rw-r--r--nuttx/arch/avr/src/avr32/avr32_internal.h2
-rw-r--r--nuttx/arch/avr/src/avr32/up_dumpstate.c2
-rw-r--r--nuttx/arch/avr/src/avr32/up_nommuhead.S10
3 files changed, 7 insertions, 7 deletions
diff --git a/nuttx/arch/avr/src/avr32/avr32_internal.h b/nuttx/arch/avr/src/avr32/avr32_internal.h
index 3d45f6c54..bcac8074a 100644
--- a/nuttx/arch/avr/src/avr32/avr32_internal.h
+++ b/nuttx/arch/avr/src/avr32/avr32_internal.h
@@ -79,7 +79,7 @@ extern volatile uint32_t *current_regs;
* heap is CONFIG_DRAM_END
*/
-extern uint32_t g_heapbase;
+extern uint32_t g_idle_topstack;
#endif /* __ASSEMBLY__ */
diff --git a/nuttx/arch/avr/src/avr32/up_dumpstate.c b/nuttx/arch/avr/src/avr32/up_dumpstate.c
index 32db56f0d..90cb22837 100644
--- a/nuttx/arch/avr/src/avr32/up_dumpstate.c
+++ b/nuttx/arch/avr/src/avr32/up_dumpstate.c
@@ -158,7 +158,7 @@ void up_dumpstate(void)
if (rtcb->pid == 0)
{
- ustackbase = g_heapbase - 4;
+ ustackbase = g_idle_topstack - 4;
ustacksize = CONFIG_IDLETHREAD_STACKSIZE;
}
else
diff --git a/nuttx/arch/avr/src/avr32/up_nommuhead.S b/nuttx/arch/avr/src/avr32/up_nommuhead.S
index 316e68aaf..149b1f26f 100644
--- a/nuttx/arch/avr/src/avr32/up_nommuhead.S
+++ b/nuttx/arch/avr/src/avr32/up_nommuhead.S
@@ -141,17 +141,17 @@ __start:
.word up_lowinit
.size __start, .-__start
/* This global variable is unsigned long g_heapbase and is
* exported from here only because of its coupling to other
* uses of _ebss in this file
*/
.data
.align 4
- .globl g_heapbase
- .type g_heapbase, object
-g_heapbase:
+ .globl g_idle_topstack
+ .type g_idle_topstack, object
+g_idle_topstack:
.long _ebss+CONFIG_IDLETHREAD_STACKSIZE
- .size g_heapbase, .-g_heapbase
+ .size g_idle_topstack, .-g_idle_topstack
.end
@@ -141,17 +141,17 @@ __start:
.word up_lowinit
.size __start, .-__start
- /* This global variable is unsigned long g_heapbase and is
+ /* This global variable is unsigned long g_idle_topstack and is
* exported from here only because of its coupling to other
* uses of _ebss in this file